@@ -758,6 +758,32 @@ class account():
             result = note.system_note_infoprint(msg)
             return False
 
+    def FavouriteTweet(self, widget, id, *args):
+        
+        try:
+                
+                data = self.api.CreateFavoriteForID(id)
+                note = osso.SystemNote(self.osso_c)
+                result = note.system_note_infoprint("Favourite Tweet set ")
+        except IOError, e:
+            print "error"
+            msg = 'Error favouriting ' + str(id) + ' '
+            if hasattr(e, 'reason'):
+                msg = msg + str(e.reason)
+
+            if hasattr(e, 'code'):
+                if (e.code == 401):
+                    reason = "Not authorised: check uid/pwd"
+                elif(e.code == 503):
+                    reason = "Service unavailable"
+                else:
+                    reason = ""
+                msg = msg + 'Server returned ' + str(e.code) + " : " + reason
+
+            note = osso.SystemNote(self.osso_c)
+            note.system_note_dialog(msg)
+            print msg
+
     def FollowUser(self, widget, name, *args):
         #strip out the @ which isn't really part of the username
         name = name.replace("@", "")
