@@ -302,6 +302,14 @@ class Witter():
         self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", (url,))
 
         print "We tried to open a browser"
+        
+    def FavouriteTweet(self, widget, id, *args):
+        #open a url in a browser
+
+        print "Favourite the tweet"
+        #webbrowser.open_new(url)
+        self.activeAccount.FavouriteTweet(self,long(id))
+        print "tweet set as favourite"
 
     def Translate(self, widget, text, *args):
         #open a url in a browser
